@@ -35,7 +35,7 @@ USAGE_FLAG_SUPRESS_G_DEBUG_FLAG = 0x02
 USAGE_FLAG_FILE_ARGS = 0x04
 
 
-
+uiscan=False
 class Module(object):
     def __init__(self, mod, title, version, doc,
                  usage_data=None, avail_modes=None,
@@ -79,6 +79,10 @@ class Module(object):
             self.installed_ui_toolkits.append(UI_TOOLKIT_QT4)
             self.num_installed_ui_toolkits += 1
 
+        if utils.to_bool(sys_conf.get('configure', 'qt5', '0')):
+            self.installed_ui_toolkits.append(UI_TOOLKIT_QT5)
+            self.num_installed_ui_toolkits += 1
+
         self.default_mode = INTERACTIVE_MODE
 
         self.num_valid_modes = 0
@@ -109,8 +113,8 @@ class Module(object):
                 self.default_ui_toolkit = 'none'
 
             elif (UI_TOOLKIT_QT4 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt4' and UI_TOOLKIT_QT4 in self.installed_ui_toolkits) or \
-                 (UI_TOOLKIT_QT3 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt3' and UI_TOOLKIT_QT3 in self.installed_ui_toolkits):
-
+                 (UI_TOOLKIT_QT3 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt3' and UI_TOOLKIT_QT3 in self.installed_ui_toolkits) or \
+                 (UI_TOOLKIT_QT5 in self.supported_ui_toolkits and self.default_ui_toolkit == 'qt5' and UI_TOOLKIT_QT5 in self.installed_ui_toolkits):
                 self.default_mode = GUI_MODE
 
             elif self.default_ui_toolkit == 'qt3' and UI_TOOLKIT_QT3 not in self.supported_ui_toolkits:
@@ -118,6 +122,9 @@ class Module(object):
                 if UI_TOOLKIT_QT4 in self.supported_ui_toolkits and UI_TOOLKIT_QT4 in self.installed_ui_toolkits: # (e.g, hp-linefeedcal?)
                     self.default_ui_toolkit = 'qt4'
                     self.default_mode = GUI_MODE
+                if UI_TOOLKIT_QT5 in self.supported_ui_toolkits and UI_TOOLKIT_QT5 in self.installed_ui_toolkits:
+                    self.default_ui_toolkit = 'qt5'
+                    self.default_mode = GUI_MODE
 
                 elif INTERACTIVE_MODE in self.avail_modes:
                     self.default_mode = INTERACTIVE_MODE
@@ -205,6 +212,10 @@ class Module(object):
             if UI_TOOLKIT_QT4 in self.supported_ui_toolkits and UI_TOOLKIT_QT4 in self.installed_ui_toolkits:
                 content.append(utils.USAGE_USE_QT4)
 
+            if UI_TOOLKIT_QT5 in self.supported_ui_toolkits and UI_TOOLKIT_QT5 in self.installed_ui_toolkits:
+                content.append(utils.USAGE_USE_QT5)
+                
+
         content.append(utils.USAGE_LOGGING1)
         content.append(utils.USAGE_LOGGING2)
         if include_flags & USAGE_FLAG_SUPRESS_G_DEBUG_FLAG != USAGE_FLAG_SUPRESS_G_DEBUG_FLAG:
@@ -300,6 +311,7 @@ class Module(object):
         show_usage = None
         device_uri = None
         printer_name = None
+        uiscan=False
         error_msg = []
         mode = self.default_mode
         if prop.gui_build:
@@ -357,6 +369,9 @@ class Module(object):
 
                 elif o == '--help-desc':
                     show_usage = 'desc'
+                
+                elif o == '--uiscan':
+                    uiscan = True
 
                 elif o in ('--qt3', '--use-qt3'):
                     if self.avail_modes is not None and GUI_MODE in self.avail_modes:
@@ -379,6 +394,18 @@ class Module(object):
                             ui_toolkit = 'qt4'
                         else:
                             error_msg.append("%s does not support Qt4. Unable to enter GUI mode." % self.mod)
+ 
+                elif o in ('--qt5', '--use-qt5'):
+                    if self.avail_modes is not None and GUI_MODE in self.avail_modes:
+                        if self.supported_ui_toolkits is not None and \
+                            UI_TOOLKIT_QT5 in self.supported_ui_toolkits and prop.gui_build and \
+                            UI_TOOLKIT_QT5 in self.installed_ui_toolkits:
+
+                            mode = GUI_MODE
+                            ui_toolkit = 'qt5'
+                        else:
+                            error_msg.append("%s does not support Qt4. Unable to enter GUI mode." % self.mod)
+               
 
                 #elif o in ('--lang', '--loc'):
                 #    if a.strip() == '?':
@@ -393,12 +420,14 @@ class Module(object):
 
         if self.help_only_support:
             if show_usage or error_msg:
-                self.usage(show_usage, error_msg)
+                if uiscan == False:
+                    self.usage(show_usage, error_msg)
             else:
                 log.info(log.bold("\nPlease check usage '%s --help'"%self.mod))
                 show_usage = 'text'
         else:
-            self.usage(show_usage, error_msg)
+            if uiscan == False:
+                self.usage(show_usage, error_msg)
 
         if show_usage is not None:
             sys.exit(0)
@@ -449,10 +478,13 @@ class Module(object):
             log.info("")
 
             if show_ver:
-                log.info(log.bold("HP Linux Imaging and Printing System (ver. %s)" % prop.version))
+                #if uiscan == False:
+                 log.info(log.bold("HP Linux Imaging and Printing System (ver. %s)" % prop.version))
             else:
-                log.info(log.bold("HP Linux Imaging and Printing System"))
+                #if uiscan == False:
+                 log.info(log.bold("HP Linux Imaging and Printing System"))
 
+            #if uiscan == False:
             log.info(log.bold("%s ver. %s" % (self.title, self.version)))
             log.info("")
             log.info("Copyright (c) 2001-15 HP Development Company, LP")
