@@ -31,11 +31,20 @@ import getopt
 import time
 import os
 
+
+
 # Local
 from base.g import *
 from base import device, status, utils, tui, module
 from prnt import cups
 
+try:
+    from importlib import import_module
+except ImportError as e:
+    log.debug(e)
+    from base.utils import dyn_import_mod as import_module
+
+
 try:
     restrict = True
 
@@ -45,7 +54,7 @@ try:
 
 
     mod = module.Module(__mod__, __title__, __version__, __doc__, None,
-                        (INTERACTIVE_MODE, GUI_MODE), (UI_TOOLKIT_QT4,),
+                        (INTERACTIVE_MODE, GUI_MODE), (UI_TOOLKIT_QT4, UI_TOOLKIT_QT5),
                         False, devid_mode)
 
     mod.setUsage(module.USAGE_FLAG_DEVICE_ARGS,
@@ -162,16 +171,12 @@ try:
             d.close()
 
     else: # GUI mode
-        try:
-            from PyQt4.QtGui import QApplication
-            from ui4.infodialog import InfoDialog
-        except ImportError:
-            log.error("Unable to load Qt4 support. Is it installed?")
-            sys.exit(1)
+        QApplication, ui_package = utils.import_dialog(ui_toolkit)
+        ui = import_module(ui_package + ".infodialog")
 
         if 1:
             app = QApplication(sys.argv)
-            dlg = InfoDialog(None, device_uri)
+            dlg = ui.InfoDialog(None, device_uri)
             dlg.show()
             try:
                 log.debug("Starting GUI loop...")
