@@ -32,17 +32,25 @@ import getopt
 import re
 import time
 
+
 # Local
 from base.g import *
 from base import device, utils, tui, module
 from prnt import cups
 
 
+try:
+    from importlib import import_module
+except ImportError as e:
+    log.debug(e)
+    from base.utils import dyn_import_mod as import_module
+
+
 
 try:
     mod = module.Module(__mod__, __title__, __version__, __doc__, None,
                         (INTERACTIVE_MODE, GUI_MODE),
-                        (UI_TOOLKIT_QT4,))
+                        (UI_TOOLKIT_QT4, UI_TOOLKIT_QT5))
 
     mod.setUsage(module.USAGE_FLAG_DEVICE_ARGS)
 
@@ -62,18 +70,20 @@ try:
             mode = INTERACTIVE_MODE
 
     if mode == GUI_MODE:
-        try:
-            from PyQt4.QtGui import QApplication
-            from ui4.printtestpagedialog import PrintTestPageDialog
-        except ImportError:
-            log.error("Unable to load Qt4 support. Is it installed?")
-            sys.exit(1)
+        # try:
+        #     from PyQt4.QtGui import QApplication
+        #     from ui4.printtestpagedialog import PrintTestPageDialog
+        # except ImportError:
+        #     log.error("Unable to load Qt4 support. Is it installed?")
+        #     sys.exit(1)
+        QApplication, ui_package = utils.import_dialog(ui_toolkit)
+        ui = import_module(ui_package + ".printtestpagedialog")
 
         log.set_module("%s(UI)" % __mod__)
 
         if 1:
             app = QApplication(sys.argv)
-            dialog = PrintTestPageDialog(None, printer_name)
+            dialog = ui.PrintTestPageDialog(None, printer_name)
             dialog.show()
             try:
                 log.debug("Starting GUI loop...")
